@@ -7,6 +7,7 @@ but merely provides the workhorse for finding and manipulating colors.
 With the ``Style`` class, any color can be directly called or given to a with statement.
 """
 
+from __future__ import annotations
 
 import contextlib
 import os
@@ -15,7 +16,7 @@ import re
 import sys
 from abc import ABCMeta, abstractmethod
 from copy import copy
-from typing import IO, Dict, Optional, Union
+from typing import IO, ClassVar
 
 from .names import (
     FindNearest,
@@ -171,6 +172,8 @@ class Color:
             number = FindNearest(*self.rgb).only_simple()
         elif self.representation in (3, 4):
             number = FindNearest(*self.rgb).all_fast()
+        else:
+            raise AssertionError("Invalid representation, needs to be 0-4")
 
         if self.number is None:
             self.number = number
@@ -340,13 +343,15 @@ class Style(metaclass=ABCMeta):
     """The class of color to use. Never hardcode ``Color`` call when writing a Style
     method."""
 
-    attribute_names: Union[Dict[str, str], Dict[str, int]]
+    # These must be defined by subclasses
+    # pylint: disable-next=declare-non-slot
+    attribute_names: ClassVar[dict[str, str] | dict[str, int]]
 
-    _stdout: Optional[IO] = None
+    _stdout: IO | None = None
     end = "\n"
     """The endline character. Override if needed in subclasses."""
 
-    ANSI_REG = re.compile("\033" + r"\[([\d;]+)m")
+    ANSI_REG = re.compile("\033\\[([\\d;]+)m")
     """The regular expression that finds ansi codes in a string."""
 
     @property
@@ -385,8 +390,7 @@ class Style(metaclass=ABCMeta):
 
     @classmethod
     def from_color(cls, color):
-        self = cls(fgcolor=color) if color.fg else cls(bgcolor=color)
-        return self
+        return cls(fgcolor=color) if color.fg else cls(bgcolor=color)
 
     def invert(self):
         """This resets current color(s) and flips the value of all
@@ -575,7 +579,6 @@ class Style(metaclass=ABCMeta):
     def __eq__(self, other):
         """Equality is true only if reset, or if attributes, fg, and bg match."""
         if type(self) == type(other):
-
             if self.isreset:
                 return other.isreset
 
@@ -657,7 +660,7 @@ class Style(metaclass=ABCMeta):
                 else:
                     raise ColorNotFound(f"The code {value} is not recognised")
         except StopIteration:
-            return
+            pass
 
     @classmethod
     def string_filter_ansi(cls, colored_string):
@@ -737,20 +740,19 @@ class HTMLStyle(Style):
     actually can be a handy way to quickly color html text."""
 
     __slots__ = ()
-    attribute_names = dict(
-        bold="b",
-        em="em",
-        italics="i",
-        li="li",
-        underline='span style="text-decoration: underline;"',
-        code="code",
-        ol="ol start=0",
-        strikeout="s",
-    )
+    attribute_names = {
+        "bold": "b",
+        "em": "em",
+        "italics": "i",
+        "li": "li",
+        "underline": 'span style="text-decoration: underline;"',
+        "code": "code",
+        "ol": "ol start=0",
+        "strikeout": "s",
+    }
     end = "<br/>\n"
 
     def __str__(self):
-
         if self.isreset:
             raise ResetNotSupported("HTML does not support global resets!")
 
@@ -764,7 +766,7 @@ class HTMLStyle(Style):
             if self.attributes[attr]:
                 result += "<" + self.attribute_names[attr] + ">"
 
-        for attr in reversed(sorted(self.attributes)):
+        for attr in sorted(self.attributes, reverse=True):
             if not self.attributes[attr]:
                 result += "</" + self.attribute_names[attr].split(" ")[0] + ">"
         if self.fg and self.fg.isreset:
